package com.scrdev.pg.kokotimeapp.movies;

import java.io.Serializable;

/**
 * 
 * @author Scrdev part of Kokotime copyright 2017
 *
 */
public class MovieItem implements Serializable {

	
	private static final long serialVersionUID = 1L;
	
	/**
	 * All the variables can be set by direct access to the variable from the instance of 
	 * the object no need for setters and getters they are only there for your convenience
	 */
	
	/*
	 * A custom id you can add, if not set the app will use the name for identification
	 */
	long id = 0; 
	
	
	String name;
	String thumbLink;
	/**
	 * the url of the curent movie if available, can be 
	 * accessed later on when item is passed bacl to you
	 */
	String websiteLink;
	String description;
	String releaseDate;
	String rating;
	int currentlyWatchingPosition = 0;
	int totalDuration = 0;
	
	/**
	 * date of upcomming if movie will be added soon 
	 */
	String upcomingDate;
	
    /**
     * Indicates to the app that this MovieItem does not have videosources and should redirect the user to the website in the websiteLink variable
     */
    private boolean isExternalSource = false;
    
	private boolean trailerAvailable = false;
	private String price = null;
    

	
	/**
	 * sets the minimum data necessary for displaying the movie item as a thumb with title
	 * @param name = name of the movie 
	 * @param thumblink = url including protocol of the image to be displayed
	 */
	
	public MovieItem(String name, String thumblink){
		this.name = name;
		this.thumbLink = thumblink.trim();
	}
	
	
	@Override
	public boolean equals(Object toCompare) {
		if (toCompare instanceof MovieItem){
			MovieItem toCompareObj = (MovieItem) toCompare;
			if (toCompareObj.getName().equals(this.name)){
				return true;
			}
			
			if (toCompareObj.getId()!=0 && toCompareObj.getId() == this.id){
				return true;
			}
		}
		return false;
	}
	
	/**
	 * sets movie data all at once instead of seperately
	 * @param description = description of the current movie, will be displayed on the info page
	 * @param releaseDate = release date of movie in text format
	 * @param rating = rating in text format
	 */
	public void setMovieData(String description, String releaseDate, String rating){
		this.description = description;
		this.releaseDate = releaseDate;
		this.rating = rating;
	}
	
	public void setRating(String rating) {
		this.rating = rating;
	}
	
	
	public void setReleaseDate(String releaseDate) {
		this.releaseDate = releaseDate;
	}
	
	public void setDescription(String description) {
		this.description = description;
	}
	
	public void setWebsiteLink(String websiteLink) {
		this.websiteLink = websiteLink.trim();
	}
	
	public void setId(long id) {
		this.id = id;
	}
	
	public long getId() {
		return id;
	}
	
	public boolean isExternalSource() {
		return isExternalSource;
	}
	public void setExternalSource(boolean isExternalSource) {
		this.isExternalSource = isExternalSource;
	}
	
	
	
	/**
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 * @return if a trailer is available
	 */
	public boolean isTrailerAvailable() {
		return trailerAvailable;
	}
	
	/**
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 */
	public void setTrailerAvailable(boolean trailerAvailable) {
		this.trailerAvailable = trailerAvailable;
	}
	
	/**
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 * @return get the currewnt price set by the addon for this movie
	 */
	public String getPrice() {
		if (price!=null && price.equals("")){
			return null;
		}
		return price;
	}
	
	/**
	 * 
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 * Set the current price of the movie.
	 */
	public void setPrice(String price) {
		this.price = price;
	}
	
	
	/**
	 * Sets the current position and duration of video in milliseconds NOT TO BE
	 * USED BY ADDON
	 * @param position = position in milli
	 * @param duration = total duration in milli
	 */
	public void setCurrentlyWatchingPosition(int position, int duration){
		this.currentlyWatchingPosition = position;
		this.totalDuration = duration;
		setPrice("");
	}

	public String getName() {
		return name;
	}

	public String getThumbLink() {
		
		return thumbLink;
	}

	public String getWebsiteLink() {
		return websiteLink;
	}

	public String getDescription() {
		return description;
	}

	public String getReleaseDate() {
		return releaseDate;
	}

	public String getRating() {
		return rating;
	}

	public int getCurrentlyWatchingPosition() {
		return currentlyWatchingPosition;
	}

	public int getTotalDuration() {
		return totalDuration;
	}

	public String getUpcomingDate() {
		return upcomingDate;
	}
	
	
	
}
