package com.scrdev.pg.kokotimeapp.movies.addons;

import java.util.ArrayList;

import com.scrdev.pg.kokotimeapp.movies.MovieItem;
import com.scrdev.pg.kokotimeapp.player.VideoSource;


/**
 * 
 * 
 * @author Scrdev part of Kokotime copyright 2017
 *
 * All methods that return ArrayList<MovieItem> should not return null, if nno array is
 * available simply return an empty ArrayList
 * 
 * All methods that return ArrayList of MovieItem need to have the following values set to non null
 * values :
 * MovieItem.name
 * MovieItem.thumbLink
 * MovieItem.rating
 * MoviItem.releaseDate
 * the {@link #getUpcomming()} needs to also set MovieItem.upcommingDate
 *
 */
public interface MoviesAddonInterface {
	
	
	/**
	 * will be called by the home page to generate the tabs for genres
	 * 
	 * @return array of strings that will be passed on oe by one to the @see {@link #getPopular(String)} method
	 */
	String[] getGenreArray();
	
	/**
	 * Called by the home page to generate the top pager that displays featured content
	 * 
	 * @return ArrayList of MovieItems, avoid returning null, if no featured return empty arraylist
	 * @throws Exception any exception that might cause a crash
	 */
	ArrayList<MovieItem> getFeatured() throws Exception;
	
	/**
	 * called by the videoplayer to obtain a list of mp4 sources for the current video, to enable chromecast support
	 * your server must enable CORS
	 * 
	 * @param movieItem the movieItem for which the source is required, will include all the variable previously set by you 
	 * in the @see {@link #fillMovieInfo(MovieItem)} and the minimum required values in the MovieItem constructor
	 * @return Arraylist of VideoSource type objects 
	 * @throws Exception
	 */
	ArrayList<VideoSource> getVideoSources(MovieItem movieItem) throws Exception;
	
	/**
	 * Must fill the MovieItem values not previously set when creating the object, the minimum required values
	 * are description, rating, releaseDate 
	 * 
	 * @param movieItem the MovieItem previously created by you in 
	 * one of the other methods @see {@link #getFeatured()} {@link #search(String)} {@link #getPopular(String)} {@link #getUpcomming()} {@link #getRecentlyAdded()}
	 * @return the filled in movieItem passed as parameter,the following values need to be set to non null 
	 * values MovieItem.releaseDate, MovieItem.rating, MovieItem.description, if these values were previously set simply return the variable passed on as parameter
	 * @throws Exception
	 */
	MovieItem fillMovieInfo(MovieItem movieItem) throws Exception;
	
	
	/**
	 * Called by the apps recently added section for a list of the latest added content to the service
	 * @return an ArrayList<MovieItem> including the latest added MovieItems
	 * @throws Exception
	 */
	ArrayList<MovieItem> getRecentlyAdded() throws Exception;
	
	
	
	/**
	 * Called by the upcomming section
	 * 
	 * @return ArrayList<MovieItem> of the videos that will be added to the service, 
	 * the variable upcommingDate must be set for each MovieItem
	 * @throws Exception
	 */
	ArrayList<MovieItem> getUpcomming() throws Exception;
	
	/**
	 * Called when the user searches for content on the search section
	 * @param searchText the text entered by the user
	 * @return ArrayList<MovieItem> of the result searched text
	 * @throws Exception
	 */
	ArrayList<MovieItem> search(String searchText) throws Exception;
	
	
	/**
	 * 
	 * @param GENRE_TO_GET a genre string from the array you returned in the @see {@link #getGenreArray()} 
 	 * @return ArrayList<MovieItem> of movies corresponding the genre recievid as parameter
	 * @throws Exception
	 */
	ArrayList<MovieItem> getPopular(String GENRE_TO_GET) throws Exception;
	
	
}
