package com.scrdev.pg.kokotimeapp.series;


import java.io.Serializable;
import java.lang.reflect.Field;
import java.util.ArrayList;

/**
 * 
 * @author Scrdev part of Kokotime copyright 2017
 * 
 * SeriesItem is the object used to transport data for specific series between activities in app 
 * and between the addon and the app
 *
 */

public class SeriesItem implements Serializable, Cloneable {
    static final long serialVersionUID = 1L;

    /**
     * custom id for the current series, if no id is set the series name will be used as identification,
     * if an id is set is should not be for a specific episode but for the series itself
     */
    public long id;
    
    public String seriesName;
    public String seriesIconLink;
    
    /**
     * Url of the website, server, of the current series, not used by the app only used by addon
     */
    public String seriesLink;
    public String releaseDate;
    public String rating;
    public String description;

    /**
     * Custom temporary Uri, will not be used by the app
     */
    public String tempUri;

    
    /**
     * number of seasons for the current series
     */
    public int seasonCount;
    
    /**
     * currently watching positon,duration, episode , season
     * Managed by the app, should not be modified by addon
     */
    public int lastSeenSeason = 1;
    public int lastSeenEpisode = 1;
    public int lastSeenPosition = 0;
    public int lastSeenDuration = 0;
    
    /**
     * to be set if the movieItem is returned for the upcomming section
     */
    public String upcomingDate;
    public String upcomingEpisode;
    
    /**
     * seenEpisodes is managed by the app should not be modified by the addon
     */
    public ArrayList<String> seenEpisodes = new ArrayList<>();
    
    

    /**
     * Indicates to the app that this SeriesItem does not have videosources and should redirect the user to the website in the seriesLink variable
     */

    private boolean isExternalSource = false;

    private boolean trailerAvailable = false;
    private String price = null;
    
    /**
     * 
     * 
     * @param seriesName = name of the current series without season 
     * @param seriesIconLink = url of a poster of the current series with protocol included
     * @param seriesLink = url of the current series, will not be used by app, only for your usage
     */
    public SeriesItem(String seriesName, String seriesIconLink, String seriesLink){
        this.seriesName = seriesName;
        this.seriesIconLink = seriesIconLink;
        this.seriesLink = seriesLink;
    }
    

    @Override
    public boolean equals(Object toCompare) {

        if (toCompare instanceof SeriesItem){
            SeriesItem toCompareItem = (SeriesItem) toCompare;
            if (upcomingEpisode!=null && toCompareItem.upcomingEpisode!=null){
                if (upcomingEpisode.equals(toCompareItem.upcomingEpisode) && seriesName.equals(toCompareItem.seriesName)){
                    return true;
                }

            }
            if (seriesName.equals(toCompareItem.seriesName)){
                return true;
            }
            
            if (toCompareItem.id!= 0 && this.id == toCompareItem.id){
            	return true;
            }

        }

        return false;
    }

    /**
     * replaced by is trailer available and price to achieve the same behaviour, if you want to let the user purchase the item set this ti true for backwards 
     * compatibility.
     * @param isExternalSource
     */
    public void setExternalSource(boolean isExternalSource) {
		this.isExternalSource = isExternalSource;
	}
    
    public boolean isExternalSource() {
		return isExternalSource;
	}

 
    /**
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 * @return if a trailer is available
	 */
	public boolean isTrailerAvailable() {
		return trailerAvailable;
	}
	
	/**
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 */
	public void setTrailerAvailable(boolean trailerAvailable) {
		this.trailerAvailable = trailerAvailable;
	}
	
	/**
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 * @return get the currewnt price set by the addon for this movie
	 */
	public String getPrice() {
		if (price!=null && price.equals("")){
			return null;
		}
		return price;
	}
	
	/**
	 * 
	 * <b>Requires SDK v2, if you would like to support older versions of the SDK surround this function with 'if statement' and make sure that the app
	 * is using an sdk >= 2. You can do this by checking the {@link com.scrdev.pg.kokotimeapp.sdk.Constants#KOKOTIME_SDK_VERSION} which will change once the addon
	 * is loaded to the app. If your supported sdk version is set to 2 in your data.json file then checking compatibility is not necessary.
	 * </b>
	 * 
	 * Set the current price of the movie.
	 */
	public void setPrice(String price) {
		this.price = price;
	}
	
	

    @Override
    public Object clone() throws CloneNotSupportedException {
        return super.clone();
    }
}
